@@ -1,12 +1,23 @@
 from collections import OrderedDict
 
 import pytest
+
+try:
+    from jupyter_core.paths import prefer_environment_over_user
+except ImportError:
+    prefer_environment_over_user = None  # type:ignore
+
 from traitlets.tests.utils import check_help_all_output
 
 from jupyter_server.config_manager import BaseJSONConfigManager
-from jupyter_server.extension.serverextension import _get_config_dir
-from jupyter_server.extension.serverextension import toggle_server_extension_python
-
+from jupyter_server.extension.serverextension import (
+    DisableServerExtensionApp,
+    ListServerExtensionsApp,
+    ServerExtensionApp,
+    ToggleServerExtensionApp,
+    _get_config_dir,
+    toggle_server_extension_python,
+)
 
 # Use ServerApps environment because it monkeypatches
 # jupyter_core.paths and provides a config directory
@@ -42,6 +53,7 @@ def test_disable(jp_env_config_path, jp_extension_environ):
     assert not config["mock1"]
 
 
+@pytest.mark.skipif(prefer_environment_over_user is None, reason="Requires jupyter_core 5.0+")
 def test_merge_config(jp_env_config_path, jp_configurable_serverapp, jp_extension_environ):
     # Toggle each extension module with a JSON config file
     # at the sys-prefix config dir.
@@ -61,28 +73,28 @@ def test_merge_config(jp_env_config_path, jp_configurable_serverapp, jp_extensio
     # when these two configs merge.
     toggle_server_extension_python(
         "tests.extension.mockextensions.mockext_both",
-        enabled=True,
+        enabled=False,
         sys_prefix=True,
     )
     toggle_server_extension_python(
         "tests.extension.mockextensions.mockext_both",
-        enabled=False,
+        enabled=True,
         user=True,
     )
 
-    arg = "--ServerApp.jpserver_extensions={{'{mockext_py}': True}}".format(
-        mockext_py="tests.extension.mockextensions.mockext_py"
-    )
+    mockext_py = "tests.extension.mockextensions.mockext_py"
+    argv = ["--ServerApp.jpserver_extensions", f"{mockext_py}=True"]
 
     # Enable the last extension, mockext_py, using the CLI interface.
-    app = jp_configurable_serverapp(config_dir=str(jp_env_config_path), argv=[arg])
+    app = jp_configurable_serverapp(config_dir=str(jp_env_config_path), argv=argv)
     # Verify that extensions are enabled and merged in proper order.
     extensions = app.jpserver_extensions
     assert extensions["tests.extension.mockextensions.mockext_user"]
     assert extensions["tests.extension.mockextensions.mockext_sys"]
     assert extensions["tests.extension.mockextensions.mockext_py"]
     # Merging should causes this extension to be disabled.
-    assert not extensions["tests.extension.mockextensions.mockext_both"]
+    if prefer_environment_over_user():
+        assert not extensions["tests.extension.mockextensions.mockext_both"]
 
 
 @pytest.mark.parametrize(
@@ -104,3 +116,21 @@ def test_load_ordered(jp_serverapp, jp_server_config):
     assert jp_serverapp.mockII is True, "Mock II should have been loaded"
     assert jp_serverapp.mockI is True, "Mock I should have been loaded"
     assert jp_serverapp.mock_shared == "II", "Mock II should be loaded after Mock I"
+
+
+def test_server_extension_apps(jp_env_config_path, jp_extension_environ):
+    app = ToggleServerExtensionApp()
+    app.extra_args = ["mock1"]
+    app.start()
+
+    app2 = DisableServerExtensionApp()
+    app2.extra_args = ["mock1"]
+    app2.start()
+
+    app3 = ListServerExtensionsApp()
+    app3.start()
+
+
+def test_server_extension_app():
+    app = ServerExtensionApp()
+    app.launch_instance(["list"])
